summaryrefslogtreecommitdiff
path: root/src/mesa/drivers/dri/intel/intel_regions.h
diff options
context:
space:
mode:
authorEric Anholt <eric@anholt.net>2010-06-07 09:52:57 -0700
committerEric Anholt <eric@anholt.net>2010-06-08 13:42:02 -0700
commit34474fa4119378ef9fbb9fb557cc19c0a1ca1f7e (patch)
tree0d0a246b981cc60fc70d6cf6103b05d0df045c23 /src/mesa/drivers/dri/intel/intel_regions.h
parent22409756d4ed941f2ec6729ab0c312149749106f (diff)
intel: Change dri_bo_* to drm_intel_bo* to consistently use new API.
The slightly less mechanical change of converting the emit_reloc calls will follow.
Diffstat (limited to 'src/mesa/drivers/dri/intel/intel_regions.h')
-rw-r--r--src/mesa/drivers/dri/intel/intel_regions.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/src/mesa/drivers/dri/intel/intel_regions.h b/src/mesa/drivers/dri/intel/intel_regions.h
index 2459c9a924..6bbed32f2a 100644
--- a/src/mesa/drivers/dri/intel/intel_regions.h
+++ b/src/mesa/drivers/dri/intel/intel_regions.h
@@ -30,8 +30,9 @@
/** @file intel_regions.h
*
* Structure definitions and prototypes for intel_region handling, which is
* the basic structure for rectangular collections of pixels stored in a dri_bo.
*/
#include <xf86drm.h>
@@ -134,9 +135,9 @@ void intel_region_release_pbo(struct intel_context *intel,
void intel_region_cow(struct intel_context *intel,
struct intel_region *region);
-dri_bo *intel_region_buffer(struct intel_context *intel,
- struct intel_region *region,
- GLuint flag);
+drm_intel_bo *intel_region_buffer(struct intel_context *intel,
+ struct intel_region *region,
+ GLuint flag);
void _mesa_copy_rect(GLubyte * dst,
GLuint cpp,
@@ -30,8 +30,9 @@
/** @file intel_regions.h
*
- * Structure definitions and prototypes for intel_region handling, which is
- * the basic structure for rectangular collections of pixels stored in a dri_bo.
+ * Structure definitions and prototypes for intel_region handling,
+ * which is the basic structure for rectangular collections of pixels
+ * stored in a drm_intel_bo.
*/
#include <xf86drm.h>